
.. _`contact channels`:
.. _`contact`:

Contact channels
================

Web
---

- `pytest issue tracker`_ to report bugs or suggest features.
- `pytest discussions`_ at GitHub for general questions.
- `pytest on stackoverflow.com <http://stackoverflow.com/search?q=pytest>`_
  to post precise questions with the tag ``pytest``.  New questions will usually
  be seen by pytest users or developers and answered quickly.

Chat
----

- `pytest discord server <https://discord.com/invite/pytest-dev>`_
  for pytest development visibility and general assistance.
- ``#pytest`` `on irc.libera.chat <ircs://irc.libera.chat:6697/#pytest>`_ IRC
  channel for random questions (using an IRC client, or `via webchat
  <https://web.libera.chat/#pytest>`_)
- ``#pytest`` `on Matrix <https://matrix.to/#/#pytest:matrix.org>`_.

Microblogging
-------------

- Bluesky: `@pytest.org <https://bsky.app/profile/pytest.org>`_
- Mastodon: `@pytest@fosstodon.org <https://fosstodon.org/@pytest>`_
- Twitter/X: `@pytestdotorg <https://x.com/pytestdotorg>`_

Mail
----

- `Testing In Python`_: a mailing list for Python testing tools and discussion.
- Mail to `core@pytest.org <mailto:core@pytest.org>`_ for topics that cannot be
  discussed in public. Mails sent there will be distributed among the members
  in the pytest core team, who can also be contacted individually:

  * Bruno Oliveira (:user:`nicoddemus`, `bruno@pytest.org <mailto:bruno@pytest.org>`_)
  * Freya Bruhin (:user:`The-Compiler`, `freya@pytest.org <mailto:freya@pytest.org>`_)
  * Pierre Sassoulas (:user:`Pierre-Sassoulas`, `pierre@pytest.org <mailto:pierre@pytest.org>`_)
  * Ran Benita (:user:`bluetech`, `ran@pytest.org <mailto:ran@pytest.org>`_)
  * Ronny Pfannschmidt (:user:`RonnyPfannschmidt`, `ronny@pytest.org <mailto:ronny@pytest.org>`_)
  * Zac Hatfield-Dodds (:user:`Zac-HD`, `zac@pytest.org <mailto:zac@pytest.org>`_)

Other
-----

- The :doc:`contribution guide <contributing>` for help on submitting pull
  requests to GitHub.
- Freya Bruhin (:user:`The-Compiler`) offers pytest professional teaching and
  consulting via `Bruhin Software <https://bruhin.software>`_.

.. _`pytest issue tracker`: https://github.com/pytest-dev/pytest/issues
.. _`pytest discussions`: https://github.com/pytest-dev/pytest/discussions
.. _`Testing in Python`: http://lists.idyll.org/listinfo/testing-in-python
